@@ -61,14 +61,17 @@ dict(
     span = const.TEXT_ZONE_CHARACTER,
 ).get
 
-djvu_zone_to_hocr = {
+_djvu_zone_to_hocr = {
     const.TEXT_ZONE_PAGE: ('div', 'ocr_page'),
     const.TEXT_ZONE_COLUMN: ('div', 'ocr_carea'),
     const.TEXT_ZONE_PARAGRAPH: ('p', 'ocr_par'),
     const.TEXT_ZONE_REGION: ('span', 'ocrx_block'),
     const.TEXT_ZONE_LINE: ('span', 'ocrx_line'),
     const.TEXT_ZONE_WORD: ('span', 'ocrx_word'),
-}.__getitem__
+}
+djvu2hocr_capabilities = list(sorted(cls for tag, cls in _djvu_zone_to_hocr.itervalues()))
+djvu_zone_to_hocr = _djvu_zone_to_hocr.__getitem__
+del _djvu_zone_to_hocr
 
 image_re = re.compile(
     r'''
@@ -291,6 +294,8 @@ def _replace_text(djvu_class, title, text, settings):
                 continue
             bbox = BBox()
             for k in xrange(i, j):
+                if settings.cuneiform and coordinates[k] == (-1, -1, -1, -1):
+                    raise errors.MalformedHocr("missing bbox for non-whitespace character")
                 bbox.update(BBox(*coordinates[k]))
             last_word = Zone(type=const.TEXT_ZONE_WORD, bbox=bbox)
             words += last_word,
@@ -338,6 +343,8 @@ def _rotate(obj, rotation, xform=None):
 
 def _scan(node, buffer, parent_bbox, settings):
     def look_down(buffer, parent_bbox):
+        if node.text and node.text.strip():
+            buffer += node.text,
         for child in node.iterchildren():
             _scan(child, buffer, parent_bbox, settings)
             if child.tail:
@@ -345,8 +352,6 @@ def _scan(node, buffer, parent_bbox, settings):
                     buffer += child.tail,
                 else:
                     buffer += Space(),
-        if node.text and node.text.strip():
-            buffer += node.text,
     if not isinstance(node.tag, basestring):
         return
     if settings.cuneiform and settings.cuneiform <= (0, 8):
@@ -402,7 +407,7 @@ def _scan(node, buffer, parent_bbox, settings):
             bboxes_node = node.find('span[@class="ocr_cinfo"]')
             if bboxes_node is not None and len(bboxes_node) == 0 and bboxes_node.text is None:
                 title = bboxes_node.get('title') or ''
-        result[-1:] = _replace_text(djvu_class, title, result[-1], settings)
+        result[:] = _replace_text(djvu_class, title, ''.join(result), settings)
     elif settings.cuneiform and settings.cuneiform <= (0, 8) and djvu_class is const.TEXT_ZONE_PARAGRAPH:
         result[:] = _replace_cuneiform08_paragraph(result[:], settings)
     if not bbox and not len(node):
